@@ -62,13 +62,14 @@ public:	//Helper functions
 	 * Save cell state as text
 	 * \return cell description
 	 */
-	string Save() const;
+	unsigned short Save() const;
 
 	/**
 	 * Load cell state from text
 	 * \param state cell description
+	 * \return false if load failed
 	 */
-	void Load(const string& state);
+	bool Load(const unsigned short state);
 
 	/**
 	 * Reverse lock state of the cell
